.. :changelog:

History
-------

0.0.1 (26-02-2019)
---------------------

* First code creation


0.1.0 (26-02-2019)
------------------

* First public release


0.1.1 (29-09-2020)
------------------

* Updated quaratine path logic


0.1.2 (02-10-2020)
------------------

* Fix for get_project method


0.1.3 (02-10-2020)
------------------

* Fixed project_group name logic


0.2.0 (16-10-2020)
------------------

* Implemented web identity authentication.


0.2.1 (16-10-2020)
------------------

* Bumped dependencies


1.0.0 (30-12-2020)
------------------

* Replace hyphens with underscores in all project names for dynamo lookup.


1.0.1 (07-01-2021)
------------------

* Made error message friendlier.


1.0.2 (09-03-2021)
------------------

* Explicitly targeting the copy git repo for the latest gitlab.


1.1.0 (16-03-2021)
------------------

* Implemented archive instead of checkout as checkout corrupted repositories in Gitlab after 13.8 and the exposure of GIT_DIR environment variable.
